if string.lower(RequiredScript) == "lib/managers/raidexperiencemanager" then
	function RaidExperienceManager:calculate_exp_brakedown(mission_id, operation_id, success)
		local exp_table = {
			additive = {},
			multiplicative = {}
		}
		local base_id = operation_id or mission_id
		local event_additive = {
			id = "xp_additive_event"
		}

		if operation_id then
			if table.index_of(game_state_machine:current_state():job_data().events_index, mission_id) == #game_state_machine:current_state():job_data().events_index then
				local operation_additive = {
					id = "xp_additive_operation",
					amount = tweak_data.operations.missions[operation_id].xp
				}

				table.insert(exp_table.additive, operation_additive)
			end

			event_additive.amount = tweak_data.operations.missions[operation_id].events[mission_id].xp
		else
			event_additive.amount = tweak_data.operations.missions[mission_id].xp
		end

		table.insert(exp_table.additive, event_additive)

		if self._loot_bonus_xp then
			local bonus_xp_additive = {
				id = "menu_loot_screen_bonus_xp_points",
				amount = self._loot_bonus_xp
			}

			table.insert(exp_table.additive, bonus_xp_additive)
			self:clear_loot_bonus_xp()
		end

		local card_additive = {
			id = "xp_additive_card",
			amount = game_state_machine:current_state():card_bonus_xp()
		}

		table.insert(exp_table.additive, card_additive)

		if self._loot_redeemed_xp then
			local loot_redeemed = {
				id = "xp_additive_loot_redeemed",
				amount = self._loot_redeemed_xp
			}

			table.insert(exp_table.additive, loot_redeemed)
		end

		if not success then
			local event_fail_multiplicative = {
				id = "xp_multiplicative_event_fail",
				amount = tweak_data:get_value("experience_manager", "level_failed_multiplier") - 1
			}

			table.insert(exp_table.multiplicative, event_fail_multiplicative)
		end

		if tweak_data.operations.missions[base_id].stealth_bonus and table.contains(self._global.mission_xp, RaidExperienceManager.SCRIPT_XP_EVENT_STEALTH) then
			local stealth_multiplicative = {
				id = "xp_multiplicative_stealth",
				amount = tweak_data.operations.missions[base_id].stealth_bonus - 1
			}

			table.insert(exp_table.multiplicative, stealth_multiplicative)
		end

		local card_multiplicative = {
			id = "xp_multiplicative_card",
			amount = game_state_machine:current_state():card_xp_multiplier() - 1
		}

		table.insert(exp_table.multiplicative, card_multiplicative)

		local num_players_multiplicative = {
			id = "xp_multiplicative_num_players",
			amount = tweak_data:get_value("experience_manager", "human_player_multiplier", managers.criminals:get_num_player_criminals() + managers.groupai:state():amount_of_winning_ai_criminals()) - 1
		}

		table.insert(exp_table.multiplicative, num_players_multiplicative)

		local difficulty_multiplicative = {
			id = "xp_multiplicative_difficulty",
			amount = tweak_data:get_value("experience_manager", "difficulty_multiplier", tweak_data:difficulty_to_index(game_state_machine._current_state._difficulty or Global.game_settings.difficulty)) - 1
		}

		table.insert(exp_table.multiplicative, difficulty_multiplicative)

		local level_difference_multiplicative = {
			id = "xp_multiplicative_level_difference",
			amount = math.lerp(1, tweak_data:get_value("experience_manager", "level_diff_max_multiplier"), self:player_level_difference() / (self:level_cap() - 1)) - 1
		}

		table.insert(exp_table.multiplicative, level_difference_multiplicative)

		return exp_table
	end
end